# Transliteration of Armenian paradigms
Western Armenian is written in the Armenian script. There are many different transliteration [systems](https://en.wikipedia.org/wiki/Romanization_of_Armenian) for Armenian, but most of them are geared to Eastern Armenian. They are not adequate for linguistic analysis. 

For this repo, I use a personal transliteration system. The transliteration was designed to simplify the description of paradigms. The transliterated form is similar to the pronunciation but not identical.

## Transliteration key
The table shows how orthgraphic characters are transliterated and pronounced, sometimes differently in special contexts. The transliterated character is similar to the pronounced IPA character.

|Orthography | Transliteration|Pronunciation|Context|
|-|-|-|-|
|ա|a|ɑ|
|է|e|ɛ|
ի|i|i|
օ|o|ɔ|
ը|ə|ə|
ե|e|jɛ|word-initial
ե|e|ɛ|elsewhere
ո|vo|vɔ|word-initial
ո|o|ɔ|elsewhere
|ու |v|v|before vowel|
|ու |u|u|elsewhere|
|փ|p|pʰ|
|բ|p|pʰ|
|պ|b|b
|թ|t|tʰ|
|դ|t|tʰ|
|տ|d|d|
|ք|k|kʰ|
|գ|k|kʰ|
|կ|g|g|
ց|t͡s|t͡sʰ|
ձ|t͡s|t͡sʰ|
ծ|d͡z|d͡z|
չ|t͡ʃ|t͡ʃʰ|
ջ|t͡ʃ|t͡ʃʰ|
ճ|d͡ʒ|d͡ʒ|
ֆ|f|f
վ|v|v
ս|s|s
զ|z|z
|շ|ʃ|ʃ
ժ|ʒ|ʒ
խ|x|χ
ղ|ɣ|ʁ|
հ|h|h
մ|m|m
ն|n|n|
լ|l|l
ռ|r|r
ր|r|r
ւ|w|v or j|
յ|j|j
՛|՛|


## Complex orthographic rules

Our transliteration does not exactly match the orthography or the surface pronunciation. Our transliteration uses the following set of changes in order to simplify the description of the morphological patterns.
1) **Digraph ու**: The letter sequence ու is traditionally transliterated as the sequence *ow*. It is pronounced as *v* before a vowel, but *u* elsewhere. Our transliteration matches the pronouncation. 
2) **Fluid ւ**: Outside of the digraph ու, the letter ւ is traditionally transliterated as *w* but it can be pronounced as *v* or *j* depending on many complicated factors. The pronounciation of this letter does not affect the paradigm rules, so we simply transliterate it as *w*. 
2) **Digraph ոյ**: The letter sequence ոյ is traditionally transliterated as the sequence *oj*. It is pronounced as *oj* before vowels or word-finally, and as *uj* elsewhere. Our transliteration matches the pronouncation.
1) **Schwa epenthesis**: A schwa is pronounced in consonant clusters but not shown in the orthography. For example, the verb դնել 'to put' is pronounced as *tənel*. The schwa does not affect the paradigm rules, so we faithfully transliterate these consonant clusters without a schwa: *tnel*.
2) **Initial ո**: The letter ո is pronounced as *o* word-medially but *vo* word-initially. The initial consonant *v* affects the paradigm rules. So we transliterate initial ո as *vo*. Note that the initial sequence ով is pronounced as *ov* without initial epenthesis. We do not represent this in our transliteration because there are no verbs with initial ով.
2) **Initial ե**: In pronunciation, the glide *j* is epenthesized before the word-initial letter ե *e*. For example, the verb երգել 'to sing' is pronounced as *jerkel*. This glide is ignored by the paradigm rules. So we do not transliterate the epenthesized glide *j*: երգել is transliterated as *erkel*. Note that the letter է is also pronounced as *e* but it doesn't trigger word-initial epenthesis: էանալ 'to exist' is pronounced *ejanal*.
1) **Silent letters**: In the orthography, the letter յ is usually pronounced as a glide *j*, but it is a silent letter word-finally. In the 3sg of verbs with the ա *a* theme vowel, the orthography shows a final glide յ *j* which is not pronounced. For example, the word կարդայ 'he reads' has a final glide յ in the spelling but it's pronounced as *garta*. We remove this silent glide in our transliteration.
2) **Glide epenthesis**: In pronuncation, vowel-vowel clusters are broken up by the glide *j*. This glide is shown in the orthography when the first vowel is ա *a*. For example, the word կարդայի 'I was reading' is pronounced as  *gartaji*, and its spelling has the glide յ *j*. But the glide is not shown in the orthography when the first vowel is anything else. For example, the word ուտէի 'I was eating' is pronounced as *udein*, but its spelling does not have a glide *j*. As a compromise between the orthography and pronunciation, we do not transliterate the glide յ *j* after ա *a*. By not encoding this phonological rule into our orthography, we have consistent forms for vowel-initial agreement suffixes.
3) **Exclamation mark**: Armenian orthography adds the exclamation mark ՛ for imperatives: *կե՛ր* 'eat!'. This mark is placed on the verb's last vowel. The mark is shown in the transliteration: *ge՛r*.
 
